<?php

/**
 * @file
 * Adjust the theme settings form to add local tweaks and options.
 *
 * https://www.drupal.org/node/177868
 *
 * /admin/appearance/settings/sector_starterkit
 *
 * This mimics what Bootstrap does in its own form_alter.
 * Beware, removing Bootstrap may break assumptions about the theme form made here.
 *
 * Creates the SVG logo source textfield so Designers can use it in their twig
 * templates.
 *
 * Implements hook_form_alter().
 */

use Drupal\block_content\Entity\BlockContent;

function sector_starterkit_form_system_theme_settings_alter(&$form, &$form_state) {

  $form['sector_starterkit'] = [
    '#type' => 'vertical_tabs',
    '#prefix' => '<h2><small>Sector settings</small></h2>',
    '#weight' => -20,
  ];

  $form['customizations'] = [
    '#type' => 'details',
    '#title' => t('Primary Brand'),
    '#group' => 'sector_starterkit',
  ];

  $form['customizations']['brand'] = [
    '#type'     => 'entity_autocomplete',
    '#title'    => t('Choose from your Sector Brand entities'),
    '#description'    => t('We\'ll use this brand to generate the icon set'),
    '#target_type' => 'block_content',
    '#selection_settings' => ['target_bundles' => ['sector_brand']],
    '#tags' => FALSE,
    '#size' => 30,
    '#maxlength' => 1024,
    '#default_value' => theme_get_setting('brand') ? BlockContent::load(theme_get_setting('brand')) : NULL,
  ];

  $form['manifest'] = [
    '#type' => 'details',
    '#title' => t('Manifest'),
    '#group' => 'sector_starterkit',
  ];
}
